BrowserPlugin class
Constructors
- BrowserPlugin({required String url, String? webViewCloseUrl, required BrowserCompletionCallback onFinishCallback, required UrlChangeCallback onUrlChange})
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- onFinishCallback → BrowserCompletionCallback
-
final
- onUrlChange → UrlChangeCallback
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- url → String
-
final
- webViewCloseUrl → String?
-
final
Methods
-
close(
) → Future< void> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
open(
) → Future< void> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited